@@ -16,6 +16,7 @@
 #include <QSignalSpy>
 #include <QTest>
 #include <QThread>
+#include <QTimer>
 
 #include <ThreadWeaver/Collection>
 #include <ThreadWeaver/DebuggingAids>
@@ -114,10 +115,10 @@ void JobTests::SimpleJobCollectionTest()
 
     Queue::instance()->finish();
 
-    QVERIFY(sequence.length() == 3);
-    QVERIFY(sequence.count('a') == 1);
-    QVERIFY(sequence.count('b') == 1);
-    QVERIFY(sequence.count('c') == 1);
+    QCOMPARE(sequence.length(), 3);
+    QCOMPARE(sequence.count('a'), 1);
+    QCOMPARE(sequence.count('b'), 1);
+    QCOMPARE(sequence.count('c'), 1);
 }
 
 void JobTests::EmptyJobCollectionTest()
@@ -374,7 +375,10 @@ void JobTests::CollectionDependenciesTest()
     QVERIFY(result.startsWith(jobC->character()));
     // QSKIP("This test is too fragile"); // PENDING(Mirko): fix
     // QTRY_COMPARE(collectionStartedSignalSpy.count(), 1);
-    loop.exec();
+    if (collectionStartedSignalSpy.count() < 1) {
+        QTimer::singleShot(5000, &loop, &QEventLoop::quit); // timeout
+        loop.exec();
+    }
     qApp->processEvents();
     QCOMPARE(collectionStartedSignalSpy.count(), 1);
     QVERIFY(Queue::instance()->isIdle());
@@ -802,12 +806,12 @@ void JobTests::ResourceRestrictionPolicyBasicsTest()
 
 void JobTests::jobStarted(JobPointer)
 {
-    QVERIFY(thread() == QThread::currentThread());
+    QCOMPARE(thread(), QThread::currentThread());
 }
 
 void JobTests::jobDone(JobPointer)
 {
-    QVERIFY(thread() == QThread::currentThread());
+    QCOMPARE(thread(), QThread::currentThread());
 }
 
 void JobTests::JobSignalsAreEmittedAsynchronouslyTest()
@@ -832,7 +836,7 @@ void JobTests::JobSignalsAreEmittedAsynchronouslyTest()
     enqueue_raw(&collection);
     QCoreApplication::processEvents();
     Queue::instance()->finish();
-    QVERIFY(sequence.length() == NumberOfBits);
+    QCOMPARE(sequence.length(), NumberOfBits);
 }
 
 QAtomicInt deliveryTestCounter;
@@ -1289,14 +1293,14 @@ void JobTests::RequestAbortCollectionTest()
     w.finish();
 
     QVERIFY(DependencyPolicy::instance().isEmpty());
-    QVERIFY(sequence.length() == 2);
-    QVERIFY(sequence.count('a') == 1);
-    QVERIFY(sequence.count('c') == 1);
-    QVERIFY(abortable.aborted == 1);
-    QVERIFY(abortable.extraCode == 0);
+    QCOMPARE(sequence.length(), 2);
+    QCOMPARE(sequence.count('a'), 1);
+    QCOMPARE(sequence.count('c'), 1);
+    QCOMPARE(abortable.aborted, 1);
+    QCOMPARE(abortable.extraCode, 0);
     QCOMPARE(jobCollection.status(), Job::Status_Aborted);
-    QVERIFY(abortable.waitForStart.tryLock() == false);
-    QVERIFY(abortable.waitForAbort.tryLock() == false);
+    QCOMPARE(abortable.waitForStart.tryLock(), false);
+    QCOMPARE(abortable.waitForAbort.tryLock(), false);
 }
 
 void JobTests::RequestAbortSequenceTest()
@@ -1320,11 +1324,11 @@ void JobTests::RequestAbortSequenceTest()
 
     QVERIFY(DependencyPolicy::instance().isEmpty());
     QCOMPARE(sequence, QLatin1String("a"));
-    QVERIFY(abortable.aborted == 1);
-    QVERIFY(abortable.extraCode == 0);
+    QCOMPARE(abortable.aborted, 1);
+    QCOMPARE(abortable.extraCode, 0);
     QCOMPARE(jobSequence.status(), Job::Status_Aborted);
-    QVERIFY(abortable.waitForStart.tryLock() == false);
-    QVERIFY(abortable.waitForAbort.tryLock() == false);
+    QCOMPARE(abortable.waitForStart.tryLock(), false);
+    QCOMPARE(abortable.waitForAbort.tryLock(), false);
 }
 
 void JobTests::JobOnFinishTest()
@@ -1340,13 +1344,13 @@ void JobTests::JobOnFinishTest()
         QCOMPARE(job.status(), Job::Status_Success);
 
         // Result should already be correct now
-        QVERIFY(sequence.length() == 3);
-        QVERIFY(sequence.count('a') == 1);
-        QVERIFY(sequence.count('b') == 1);
-        QVERIFY(sequence.count('c') == 1);
+        QCOMPARE(sequence.length(), 3);
+        QCOMPARE(sequence.count('a'), 1);
+        QCOMPARE(sequence.count('b'), 1);
+        QCOMPARE(sequence.count('c'), 1);
 
         // We should get same original instance
-        QVERIFY(&job == &jobCollection);
+        QCOMPARE(&job, &jobCollection);
 
         finishedA++;
     });
@@ -1354,9 +1358,9 @@ void JobTests::JobOnFinishTest()
     jobCollection.onFinish([&](const JobInterface &job) {
         QCOMPARE(jobCollection.status(), Job::Status_Success);
 
-        QVERIFY(sequence.length() == 3);
+        QCOMPARE(sequence.length(), 3);
         // We should get same original instance
-        QVERIFY(&job == &jobCollection);
+        QCOMPARE(&job, &jobCollection);
 
         finishedB++;
     });
@@ -1366,8 +1370,8 @@ void JobTests::JobOnFinishTest()
     w.finish();
 
     QVERIFY(DependencyPolicy::instance().isEmpty());
-    QVERIFY(finishedA == 1);
-    QVERIFY(finishedB == 1);
+    QCOMPARE(finishedA, 1);
+    QCOMPARE(finishedB, 1);
 }
 
 void JobTests::JobOnFinishAbortTest()
@@ -1393,7 +1397,7 @@ void JobTests::JobOnFinishAbortTest()
         QCOMPARE(sequence, QLatin1String("a"));
 
         // We should get same original instance
-        QVERIFY(&job == &jobSequence);
+        QCOMPARE(&job, &jobSequence);
 
         // We should be in aborted state
         QCOMPARE(job.status(), Job::Status_Aborted);
@@ -1406,7 +1410,7 @@ void JobTests::JobOnFinishAbortTest()
         QCOMPARE(sequence, QLatin1String("a"));
 
         // We should get same original instance
-        QVERIFY(&job == &jobSequence);
+        QCOMPARE(&job, &jobSequence);
 
         // We should be in aborted state
         QCOMPARE(jobSequence.status(), Job::Status_Aborted);
@@ -1419,8 +1423,8 @@ void JobTests::JobOnFinishAbortTest()
     w.finish();
 
     QVERIFY(DependencyPolicy::instance().isEmpty());
-    QVERIFY(finishedA == 1);
-    QVERIFY(finishedB == 1);
+    QCOMPARE(finishedA, 1);
+    QCOMPARE(finishedB, 1);
 }
 
 QTEST_MAIN(JobTests)
